// import 'https://cdn.jsdelivr.net/gh/orestbida/cookieconsent@3.0.1/dist/cookieconsent.umd.js';
import './cookieconsent.umd.js';


// Enable dark mode
document.documentElement.classList.add('cc--darkmode');

const categoryMapping = {
    'marketing': ['ad_storage', 'ad_user_data', 'ad_personalization'],
    'analytics': ['analytics_storage']
};

function updateGtagConsent(preferences) {
    const consentUpdate = {};
    
    for (const [category, services] of Object.entries(categoryMapping)) {
        const consentState = preferences.acceptedCategories.includes(category) ? 'granted' : 'denied';
        services.forEach(service => consentUpdate[service] = consentState);
    }
    
    gtag('consent', 'update', consentUpdate);
}

CookieConsent.run({
    guiOptions: {
        consentModal: {
            layout: "box inline",
            position: "bottom right",
            equalWeightButtons: true,
            flipButtons: true
        },
        preferencesModal: {
            layout: "box",
            position: "right",
            equalWeightButtons: true,
            flipButtons: false
        }
    },
    categories: {
        necessary: {
            readOnly: true
        },
        functionality: {},
        analytics: {},
        marketing: {}
    },
    language: {
        default: "en",
        autoDetect: "browser",
        translations: {
            en: {
                consentModal: {
                    title: "We value your privacy!",
                    description: 'We use cookies to enhance your browsing experience, serve personalized ads or content, and analyze our traffic. By clicking "Accept All", you consent to our use of cookies.',
                    acceptAllBtn: "Accept all",
                    acceptNecessaryBtn: "Reject all",
                    showPreferencesBtn: "Manage preferences",
                    footer: "Powered by <a href=\"https://2uncle.com\">2uncle</a>"
                },
                preferencesModal: {
                    title: "Consent Preferences Center",
                    acceptAllBtn: "Accept all",
                    acceptNecessaryBtn: "Reject all",
                    savePreferencesBtn: "Save preferences",
                    closeIconLabel: "Close modal",
                    serviceCounterLabel: "Service|Services",
                    sections: [
                        {
                            title: "Cookie Usage",
                            description: 'We use cookies to help you navigate efficiently and perform certain functions. You will find detailed information about all cookies under each consent category below.<br><br>The cookies that are categorized as "Necessary" are stored on your browser as they are essential for enabling the basic functionalities of the site.'
                        },
                        {
                            title: "Strictly Necessary Cookies <span class=\"pm__badge\">Always Enabled</span>",
                            description: "Necessary cookies are required to enable the basic features of this site, such as providing secure log-in or adjusting your consent preferences. These cookies do not store any personally identifiable data.",
                            linkedCategory: "necessary"
                        },
                        {
                            title: "Functionality Cookies",
                            description: "Functional cookies help perform certain functionalities like sharing the content of the website on social media platforms, collecting feedback, and other third-party features.",
                            linkedCategory: "functionality"
                        },
                        {
                            title: "Analytics Cookies",
                            description: "Analytical cookies are used to understand how visitors interact with the website. These cookies help provide information on metrics such as the number of visitors, bounce rate, traffic source, etc.",
                            linkedCategory: "analytics"
                        },
                        {
                            title: "Advertisement Cookies",
                            description: "Advertisement cookies are used to provide visitors with customized advertisements based on the pages you visited previously and to analyze the effectiveness of the ad campaigns.",
                            linkedCategory: "marketing"
                        },
                        {
                            title: "More information",
                            description: "For any query in relation to my policy on cookies and your choices, please contact us</a>."
                        }
                    ]
                }
            }
        }
    },
    onModalShow: ({ modalName }) => {
        console.log('visible:', modalName);
    },
    onFirstConsent: ({ cookie }) => {
        console.log('onFirstConsent fired', cookie);
       
      
    },

    onConsent: ({ cookie }) => {
        // console.log('onConsent fired!', cookie)
       
        // console.log( cookie.consentId);
        let preferences = CookieConsent.getUserPreferences();
        console.log(preferences);
         if( cookie.consentId.length > 0){
             document.getElementById('floatingButton').style.display = 'block';
         }
         updateGtagConsent(preferences);
    },
    onChange: ({changedCategories, changedServices}) => {
        //console.log('onChange fired!', changedCategories, changedServices);
        let preferences = CookieConsent.getUserPreferences();
   
        console.log(preferences);
        updateGtagConsent(preferences);
    },
    onModalHide: ({ modalName }) => {
        // do something
        console.log('hide')
        document.getElementById('floatingButton').style.display = 'block';

    }
});

document.getElementById('floatingButton').addEventListener('click', () => {
    document.getElementById('floatingButton').style.display = 'none';
});